==> qmmp-0.4.1.tar.bz2: qmmp-0.4.1/src/plugins/General/lyrics/translations/lyrics_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>Liedtext anzeigen</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Strg+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Liedtext-Modul</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>Über Liedtext-Modul</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp Liedtext-Modul</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from lyricsplugin.com</source>
        <translation>Dieses Modul empfängt Liedtexte von lyricsplugin.com</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="63"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="97"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Liedtext: %1 - %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>Keine Verbindung</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="85"/>
        <source>Not found</source>
        <translation>Es kann kein Liedtext für dieses Stück gefunden werden.</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="96"/>
        <source>Receiving</source>
        <translation>Daten werden empfangen</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Liedtext-Modul</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Künstler:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
</TS>

==> qmmp-0.5.2.tar.bz2: qmmp-0.5.2/src/plugins/General/lyrics/translations/lyrics_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>Lyrics</name>
    <message>
        <location filename="../lyrics.cpp" line="35"/>
        <source>View Lyrics</source>
        <translation>Liedtext anzeigen</translation>
    </message>
    <message>
        <location filename="../lyrics.cpp" line="36"/>
        <source>Ctrl+L</source>
        <translation>Strg+L</translation>
    </message>
</context>
<context>
    <name>LyricsFactory</name>
    <message>
        <location filename="../lyricsfactory.cpp" line="29"/>
        <source>Lyrics Plugin</source>
        <translation>Liedtext-Modul</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="50"/>
        <source>About Lyrics Plugin</source>
        <translation>Über Liedtext-Modul</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="51"/>
        <source>Qmmp Lyrics Plugin</source>
        <translation>Qmmp Liedtext-Modul</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../lyricsfactory.cpp" line="52"/>
        <source>This plugin retrieves lyrics from LyricWiki</source>
        <translation>Dieses Modul empfängt Liedtexte von LyricWiki</translation>
    </message>
</context>
<context>
    <name>LyricsWindow</name>
    <message>
        <location filename="../lyricswindow.cpp" line="64"/>
        <source>Done</source>
        <translation>Fertig</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="67"/>
        <location filename="../lyricswindow.cpp" line="91"/>
        <location filename="../lyricswindow.cpp" line="97"/>
        <location filename="../lyricswindow.cpp" line="105"/>
        <location filename="../lyricswindow.cpp" line="113"/>
        <location filename="../lyricswindow.cpp" line="124"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="165"/>
        <source>Lyrics: %1 - %2</source>
        <translation>Liedtext: %1 – %2</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="60"/>
        <source>No connection</source>
        <translation>Keine Verbindung</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="118"/>
        <location filename="../lyricswindow.cpp" line="153"/>
        <source>Not found</source>
        <translation>Es kann kein Liedtext für dieses Stück gefunden werden.</translation>
    </message>
    <message>
        <location filename="../lyricswindow.cpp" line="139"/>
        <location filename="../lyricswindow.cpp" line="164"/>
        <source>Receiving</source>
        <translation>Daten werden empfangen</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="14"/>
        <source>Lyrics Plugin</source>
        <translation>Liedtext-Modul</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="31"/>
        <source>Artist:</source>
        <translation>Interpret:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="41"/>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <location filename="../lyricswindow.ui" line="51"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
</context>
</TS>
